@@ -40,7 +40,7 @@ import Data.Binary (get, put)
 import Data.Binary.Put (runPut)
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
-import Data.Conduit ((.|), ConduitT, runConduitRes)
+import Data.Conduit ((.|), ConduitM, runConduitRes)
 import qualified Data.Conduit.Binary as CB
 import qualified Data.Conduit.List as CL
 import Data.Conduit.OpenPGP.Filter (conduitTKFilter, FilterPredicates(RTKFilterPredicate))
@@ -82,10 +82,11 @@ import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 
 import System.IO (Handle, hFlush, stderr, hSetBuffering, BufferMode(..))
-import qualified Text.PrettyPrint.ANSI.Leijen as PPAL
-import Text.PrettyPrint.Free ((<+>), hardline, pretty, putDoc, text)
+import Data.Text.Prettyprint.Doc ((<+>), fillSep, hardline, list, pretty)
+import Data.Text.Prettyprint.Doc.Render.Text (putDoc, hPutDoc)
+import Data.Text.Prettyprint.Convert.AnsiWlPprint (toAnsiWlPprint)
 
-grabMatchingKeysConduit :: (MonadResource m, MonadThrow m) => FilePath -> Bool -> Text -> ConduitT () TK m ()
+grabMatchingKeysConduit :: (MonadResource m, MonadThrow m) => FilePath -> Bool -> Text -> ConduitM () TK m ()
 grabMatchingKeysConduit fp filt srch = CB.sourceFile fp .| conduitGet get .| conduitToTKsDropping .| (if filt then conduitTKFilter ufp else CL.filter matchAny)
     where
         matchAny tk = either (const False) id $ fmap (keyMatchesFingerprint True tk) efp <|> fmap (keyMatchesEightOctetKeyId True tk . Right) eeok <|> return (keyMatchesUIDSubString srch tk)
@@ -132,12 +133,12 @@ tkToTKey tk = TKey {
 
 showTKey :: TKey -> IO ()
 showTKey key = putDoc $
-    text "pub  " <+> sizeabbrevkeyid (publickey key) <> hardline <>
-    mconcat (map (\x -> text "uid                           " <+> text (T.unpack x) <> hardline) (uids key)) <>
-    mconcat (map (\x -> text "sub  " <+> sizeabbrevkeyid x <> hardline) (subkeys key)) <>
+    pretty "pub  " <+> sizeabbrevkeyid (publickey key) <> hardline <>
+    mconcat (map (\x -> pretty "uid                           " <+> pretty (T.unpack x) <> hardline) (uids key)) <>
+    mconcat (map (\x -> pretty "sub  " <+> sizeabbrevkeyid x <> hardline) (subkeys key)) <>
     hardline
     where
-        sizeabbrevkeyid k = text (maybe "unknown" show (keysize k)) <> text (keyalgoabbreviation k) <> text "/0x" <> text (keyid k)
+        sizeabbrevkeyid k = pretty (maybe "unknown" show (keysize k)) <> pretty (keyalgoabbreviation k) <> pretty "/0x" <> pretty (keyid k)
 
 data Options = Options {
     keyring :: String
@@ -175,7 +176,7 @@ listO homedir = Options
     <*> pure ""
     <*> pure ""
     where
-        targetHelp = helpDoc . Just $ PPAL.text "target (which keys to output)*"
+        targetHelp = helpDoc . Just . toAnsiWlPprint $ pretty "target (which keys to output)*"
 
 graphO :: String -> Parser Options
 graphO homedir = Options
@@ -195,9 +196,9 @@ graphO homedir = Options
     <*> pure ""
     <*> pure ""
     where
-        ofhelp = helpDoc . Just $ PPAL.text "output format" <> PPAL.hardline <> PPAL.list (map (PPAL.text . show) ofchoices)
+        ofhelp = helpDoc . Just . toAnsiWlPprint $ pretty "output format" <> hardline <> list (map (pretty . show) ofchoices)
         ofchoices = [minBound..maxBound] :: [GraphOutputFormat]
-        targetHelp = helpDoc . Just $ PPAL.text "target (which keys to graph)*"
+        targetHelp = helpDoc . Just . toAnsiWlPprint $ pretty "target (which keys to graph)*"
 
 findPathsO :: String -> Parser Options
 findPathsO homedir = Options
@@ -217,9 +218,9 @@ findPathsO homedir = Options
     <*> argument str ( metavar "FROM-KEYS" <> fromHelp )
     <*> argument str ( metavar "TO-KEYS" <> toHelp )
     where
-        targetHelp = helpDoc . Just $ PPAL.text "target (which keys to use in pathfinding)*"
-        fromHelp = helpDoc . Just $ PPAL.text "from (which keys to use for the source of paths)*"
-        toHelp = helpDoc . Just $ PPAL.text "to (which keys to use for the destinations of paths)*"
+        targetHelp = helpDoc . Just . toAnsiWlPprint $ pretty "target (which keys to use in pathfinding)*"
+        fromHelp = helpDoc . Just . toAnsiWlPprint $ pretty "from (which keys to use for the source of paths)*"
+        toHelp = helpDoc . Just . toAnsiWlPprint $ pretty "to (which keys to use for the destinations of paths)*"
 
 dispatch :: Command -> IO ()
 dispatch (CmdList o) = banner' stderr >> hFlush stderr >> doList o
@@ -231,7 +232,11 @@ main :: IO ()
 main = do
     hSetBuffering stderr LineBuffering
     homedir <- getHomeDirectory
-    customExecParser (prefs showHelpOnError) (info (helper <*> versioner "hkt" <*> cmd homedir) (headerDoc (Just (banner "hkt")) <> progDesc "hOpenPGP Keyring Tool" <> footerDoc (Just (warranty "hkt")))) >>= dispatch
+    customExecParser (prefs showHelpOnError)
+                     (info (helper <*> versioner "hkt" <*> cmd homedir)
+                           (headerDoc (Just (toAnsiWlPprint (banner "hkt")))
+                           <> progDesc "hOpenPGP Keyring Tool"
+                           <> footerDoc (Just (toAnsiWlPprint (warranty "hkt"))))) >>= dispatch
 
 cmd :: String -> Parser Command
 cmd homedir = hsubparser
@@ -241,14 +246,18 @@ cmd homedir = hsubparser
    <> command "list" (info ( CmdList <$> listO homedir) ( progDesc "list matching keys" <> footerDoc (Just foot) ))
     )
     where
-        foot = PPAL.hardline <> PPAL.text "*if --filter is not specified, this must be"
-               PPAL.</> PPAL.text "a fingerprint," PPAL.</> PPAL.text "an eight-octet key ID,"
-               PPAL.</> PPAL.text "or a substring of a UID (including an empty string)" <> PPAL.hardline
-               <> PPAL.text "if --filter is specified, it must be"
-               PPAL.</> PPAL.text "something in filter syntax (see source)."
+        foot = toAnsiWlPprint $ hardline <> fillSep [
+                   pretty "*if --filter is not specified, this must be"
+                 , pretty "a fingerprint,"
+                 , pretty "an eight-octet key ID,"
+                 , pretty "or a substring of a UID (including an empty string)"]
+               <> hardline
+               <> fillSep [pretty "if --filter is specified, it must be"
+                          , pretty "something in filter syntax (see source)."
+                          ]
 
 banner' :: Handle -> IO ()
-banner' h = PPAL.hPutDoc h (banner "hkt" <> PPAL.hardline <> warranty "hkt" <> PPAL.hardline)
+banner' h = hPutDoc h (banner "hkt" <> hardline <> warranty "hkt" <> hardline)
 
 doList :: Options -> IO ()
 doList o = do
@@ -357,11 +366,9 @@ doFindPaths o = do
         JSON -> BL.putStr . A.encode $ paf
         YAML -> B.putStr . Y.encode $ paf
     putStrLn ""
-    where  -- FIXME: deduplicate this
+    where
         filt = targetIsFilter o
-        matchAny srch tk = either (const False) id $ fmap (keyMatchesFingerprint True tk) (efp srch) <|> fmap (keyMatchesEightOctetKeyId True tk . Right) (eeok srch) <|> return (keyMatchesUIDSubString srch tk)
-        efp srch = parseFingerprint srch
-        eeok srch = parseEightOctetKeyId srch
+        matchAny srch tk = either (const False) id $ fmap (keyMatchesFingerprint True tk) (parseFingerprint srch) <|> fmap (keyMatchesEightOctetKeyId True tk . Right) (parseEightOctetKeyId srch) <|> return (keyMatchesUIDSubString srch tk)
         ufpt srch = RTKFilterPredicate (parseE srch)
         parseE e = either (error . ("filter parse error: "++)) id (parseTKExp (T.unpack e)) -- this should be more specialized
 
@@ -371,7 +378,7 @@ getIssuer :: SigSubPacketPayload -> Maybe EightOctetKeyId
 hashAlgo :: SignaturePayload -> HashAlgorithm
 
 sigissuer (SigVOther 2 _) = Nothing
-sigissuer (SigV3 {}) = Nothing
+sigissuer SigV3 {} = Nothing
 sigissuer (SigV4 _ _ _ ys xs _ _) = listToMaybe . mapMaybe (getIssuer . _sspPayload) $ (ys++xs) -- FIXME: what should this be if there are multiple matches?
 sigissuer (SigVOther _ _) = error "We're in the future." -- FIXME
 
