@@ -1,4 +1,4 @@
-{-# LANGUAGE OverloadedStrings, RecordWildCards #-}
+{-# LANGUAGE RecordWildCards #-}
 
 -- hot.hs: hOpenPGP Tool
 -- Copyright © 2012-2018  Clint Adams
@@ -36,7 +36,7 @@ import Control.Monad.IO.Class (MonadIO, liftIO)
 import qualified Data.Aeson as A
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
-import Data.Conduit ((.|), ConduitT, runConduitRes, Void)
+import Data.Conduit ((.|), ConduitM, runConduitRes)
 import Data.Conduit.Serialization.Binary (conduitGet, conduitPut)
 import qualified Data.Conduit.Binary as CB
 import qualified Data.Conduit.List as CL
@@ -45,6 +45,7 @@ import Data.Binary (get, put)
 import Data.Binary.Get (Get)
 import Data.Monoid ((<>))
 import Data.Version (showVersion)
+import Data.Void (Void)
 import qualified Data.Yaml as Y
 
 import System.IO (stdin, stderr, stdout, Handle, hFlush, hPutStrLn, hSetBuffering, BufferMode(..))
@@ -52,8 +53,9 @@ import System.IO (stdin, stderr, stdout, Handle, hFlush, hPutStrLn, hSetBufferin
 import Options.Applicative.Builder (argument, command, footerDoc, headerDoc, help, helpDoc, info, long, metavar, option, eitherReader, prefs, progDesc, showDefaultWith, showHelpOnError, str, strOption, value)
 import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
-import qualified Text.PrettyPrint.ANSI.Leijen as PPAL
-import Text.PrettyPrint.Free (group, hardline, hPutDoc, Pretty, pretty)
+import Data.Text.Prettyprint.Doc ((<+>), group, hardline, list, Pretty, pretty, softline)
+import Data.Text.Prettyprint.Doc.Render.Text (hPutDoc)
+import Data.Text.Prettyprint.Convert.AnsiWlPprint (toAnsiWlPprint)
 
 data Command = DumpC DumpOptions | DeArmorC | ArmorC ArmoringOptions | FilterC FilteringOptions
 
@@ -81,16 +83,16 @@ doDump DumpOptions{..} = runConduitRes $ CB.sourceHandle stdin .| conduitGet (ge
     DumpShow -> printer
 
 -- Print every input value to standard output.
-printer :: (Show a, MonadIO m) => ConduitT a Void m ()
+printer :: (Show a, MonadIO m) => ConduitM a Void m ()
 printer = CL.mapM_ (liftIO . print)
 
-prettyPrinter :: (Pretty a, MonadIO m) => ConduitT a Void m ()
+prettyPrinter :: (Pretty a, MonadIO m) => ConduitM a Void m ()
 prettyPrinter = CL.mapM_ (liftIO . hPutDoc stdout . (<> hardline) . group . pretty)
 
-jsonSink :: (A.ToJSON a, MonadIO m) => ConduitT a Void m ()
+jsonSink :: (A.ToJSON a, MonadIO m) => ConduitM a Void m ()
 jsonSink = CL.mapM_ (liftIO . BL.putStr . flip BL.snoc 0x0a . A.encode)
 
-yamlSink :: (Y.ToJSON a, MonadIO m) => ConduitT a Void m ()
+yamlSink :: (Y.ToJSON a, MonadIO m) => ConduitM a Void m ()
 yamlSink = CL.mapM_ (liftIO . B.putStr . flip B.snoc 0x0a . Y.encode)
 
 doDeArmor :: IO ()
@@ -129,7 +131,7 @@ doP = DumpOptions
     <> showDefaultWith (drop 4 . show)
     <> ofHelp )
     where
-        ofHelp = helpDoc . Just $ PPAL.text "output format" <> PPAL.hardline <> PPAL.list (map (PPAL.text . drop 4 . show) ofchoices)
+        ofHelp = helpDoc . Just . toAnsiWlPprint $ pretty "output format" <> hardline <> list (map (pretty . drop 4 . show) ofchoices)
         ofchoices = [minBound..maxBound] :: [DumpOutputFormat]
 
 aoP :: Parser ArmoringOptions
@@ -137,13 +139,13 @@ aoP = ArmoringOptions
     <$> optional (strOption (long "comment" <> metavar "COMMENT" <> help "ASCII armor Comment field"))
     <*> option (eitherReader armorTypeReader) (long "armor-type" <> metavar "ARMORTYPE" <> armortypeHelp)
     where
-        armortypeHelp = helpDoc . Just $ PPAL.text "ASCII armor type" <> PPAL.softline <> PPAL.list (map (PPAL.text . fst) armorTypes)
+        armortypeHelp = helpDoc . Just . toAnsiWlPprint $ pretty "ASCII armor type" <> softline <> list (map (pretty . fst) armorTypes)
 
 foP :: Parser FilteringOptions
 foP = FilteringOptions
     <$> argument str ( metavar "EXPRESSION" <> filterTargetHelp )
     where
-        filterTargetHelp = helpDoc . Just $ PPAL.text "packet filter expression" PPAL.<+> PPAL.softline <> PPAL.text "see source for current syntax"
+        filterTargetHelp = helpDoc . Just . toAnsiWlPprint $ pretty "packet filter expression" <+> softline <> pretty "see source for current syntax"
 
 dispatch :: Command -> IO ()
 dispatch c = (banner' stderr >> hFlush stderr) >> dispatch' c
@@ -156,7 +158,11 @@ dispatch c = (banner' stderr >> hFlush stderr) >> dispatch' c
 main :: IO ()
 main = do
     hSetBuffering stderr LineBuffering
-    customExecParser (prefs showHelpOnError) (info (helper <*> versioner "hot" <*> cmd) (headerDoc (Just (banner "hot")) <> progDesc "hOpenPGP OpenPGP-message Tool" <> footerDoc (Just (warranty "hot")))) >>= dispatch
+    customExecParser (prefs showHelpOnError)
+                     (info (helper <*> versioner "hot" <*> cmd)
+                     (headerDoc (Just (toAnsiWlPprint (banner "hot")))
+                   <> progDesc "hOpenPGP OpenPGP-message Tool"
+                   <> footerDoc (Just (toAnsiWlPprint (warranty "hot"))))) >>= dispatch
 
 cmd :: Parser Command
 cmd = hsubparser
@@ -167,7 +173,7 @@ cmd = hsubparser
   )
 
 banner' :: Handle -> IO ()
-banner' h = PPAL.hPutDoc h (banner "hot" <> PPAL.hardline <> warranty "hot" <> PPAL.hardline)
+banner' h = hPutDoc h (banner "hot" <> hardline <> warranty "hot" <> hardline)
 
 parseExpressions :: FilteringOptions -> FilterPredicates
 parseExpressions FilteringOptions{..} = RPFilterPredicate (parseE fExpression)
